@echo off 
rem inputs should be in INPUT folder:
rem         basedata.har default.prm sets.har SplitReg.har userwgt.har
rem final outputs should appear in OUTPUT folder:
rem         basedata.har default.prm sets.har
rem other outputs should appear in WORK folder.

rem cleanup junk files
del *.inf 2>nul
del *.bak 2>nul
del *.log 2>nul
del *.gs? 2>nul
del *.min 2>nul
del *.mnc 2>nul
del *.flg 2>nul
del *.ud8 2>nul

rem ensure that work and output folders exist
md work   2>nul
md output 2>nul
rem remove all files in work and output folders
del/Q work\*.*
del/Q output\*.*

REM Split1 reads and checks new sector sets and mappings in input\SplitReg.har
REM and creates work\splitwgt.har: a dummy user file of splitting weight (to proxy userwgt.har)
call runjob split1 split1.cmf 
if errorlevel 1 goto error
if not exist input\userwgt.har copy work\splitwgt.har input\userwgt.har

REM gtp2norm turns a standard GTAP database [at input\basedata.har] into a 
REM simplified [normalized] form [at work\orig.har] which is easier to manipulate.
call runjob gtp2norm gtp2norm.cmf 
if errorlevel 1 goto error

REM next reads original GTAP data at work\orig.har to produce a standard set of
REM summaries/checks/diagnostics in work\normchk0.har  
call runjob normchek normchk0.cmf
if errorlevel 1 goto error

REM next is checking that SMRY, WSUM and WGTS headers calculated by gtp2norm
REM from original GTAP format are the same as SMRY, WSUM and WGTS headers
REM calculated by NORMCHEK for normalized format
echo doing diffhar 
diffhar work\gtp2norm.har work\normchk0.har work\diffs.har D  >diffhar0.log
if errorlevel 1 goto error

rem Perform regional split ....... could lead to unbalanced data at work\SplitReg.har
call runjob SplitReg SplitReg.cmf
if errorlevel 1 goto error

REM next reads work\SplitReg.har (which may be unbalanced) to produce a standard
REM set of summaries/checks/diagnostics in work\normchk1.har  
call runjob normchek normchk1.cmf
if errorlevel 1 goto error

REM Adjusts(makes balanced) work\SplitReg.har, output is work\adjusted.har  
call runjob gtapadjust input\gtapadjust.cmf
if errorlevel 1 goto error

REM next reads work\adjusted.har to produce a standard
REM set of summaries/checks/diagnostics in work\normchk2.har  
call runjob normchek normchk2.cmf
if errorlevel 1 goto error

REM next converts final scaled data in "normalized" format at work\adjusted.har
REM into final GTAP format files basedata.har and sets.har in output folder
call runjob norm2gtp norm2gtp.cmf 
if errorlevel 1 goto error

rem next produces standard GTAP summary/diagnostics
call runjob gtpvew gtpvew.cmf  
if errorlevel 1 goto error

rem   Next aggregates final output back to original dimensions
echo doing agghar 
agghar output\basedata.har work\reagg.har work\aggsupp.har -PM >agghar.log
if errorlevel 1 goto error
rem and checks that aggregated values match originals
echo doing diffhar 
diffhar input\basedata.har work\reagg.har work\diffs2.har D >diffhar2.log
if errorlevel 1 goto error

rem   Next is optional: uses files in output folder to run standard GTAP simulation
rem  call runjob GTAP GTAP.cmf 
rem  if errorlevel 1 goto error

echo.
echo BATCH JOB SUCCESSFUL -- see following files in output folder:
dir/b output 
goto endbat
:error
echo ###### ERROR: BATCH JOB FAILED #####
echo Check log file; most recent is listed last
dir/b/od *.log
rem  SplitCom detects errors through the existence of err.flg
dir/od *.log >err.flg
rem echo Please press CTRL-C to terminate batch job
rem pause
:endbat
